@@ -9,15 +9,11 @@ describe 'glance::api' do
 
   let :default_params do
     {
-      :debug                    => false,
-      :use_stderr               => '<SERVICE DEFAULT>',
       :bind_host                => '<SERVICE DEFAULT>',
       :bind_port                => '9292',
       :registry_host            => '0.0.0.0',
       :registry_port            => '<SERVICE DEFAULT>',
       :registry_client_protocol => '<SERVICE DEFAULT>',
-      :log_file                 => '/var/log/glance/api.log',
-      :log_dir                  => '/var/log/glance',
       :auth_strategy            => 'keystone',
       :enabled                  => true,
       :manage_service           => true,
@@ -33,6 +29,8 @@ describe 'glance::api' do
       :scrub_time               => '<SERVICE DEFAULT>',
       :default_store            => false,
       :image_cache_dir          => '/var/lib/glance/image-cache',
+      :image_import_plugins     => '<SERVICE DEFAULT>',
+      :image_conversion_output_format => '<SERVICE DEFAULT>',
       :enabled_import_methods   => '<SERVICE DEFAULT>',
       :node_staging_uri         => '<SERVICE DEFAULT>',
       :image_member_quota       => '<SERVICE DEFAULT>',
@@ -57,7 +55,6 @@ describe 'glance::api' do
   shared_examples_for 'glance::api' do
 
     [{
-        :debug                    => true,
         :bind_host                => '127.0.0.1',
         :bind_port                => '9222',
         :registry_host            => '127.0.0.1',
@@ -75,6 +72,8 @@ describe 'glance::api' do
         :delayed_delete           => 'true',
         :scrub_time               => '10',
         :image_cache_dir          => '/tmp/glance',
+        :image_import_plugins     => 'image_conversion',
+        :image_conversion_output_format => 'raw',
         :enabled_import_methods   => 'glance-direct,web-download',
         :node_staging_uri         => '/tmp/staging',
         :image_member_quota       => '128',
@@ -100,7 +99,6 @@ describe 'glance::api' do
 
         it { is_expected.to contain_class 'glance' }
         it { is_expected.to contain_class 'glance::policy' }
-        it { is_expected.to contain_class 'glance::api::logging' }
         it { is_expected.to contain_class 'glance::api::db' }
 
         it 'is_expected.to not sync the db if sync_db is set to false' do
@@ -123,7 +121,6 @@ describe 'glance::api' do
 
         it 'is_expected.to lay down default api config' do
           [
-            'use_stderr',
             'bind_host',
             'bind_port',
             'registry_host',
@@ -152,6 +149,20 @@ describe 'glance::api' do
                            "[%s]" % param_hash[:enabled_import_methods])
         end
 
+        it 'is_expected.to lay down default image_import_plugins config' do
+          # Verify brackets "[]" are added to satisfy the ListOpt syntax.
+          is_expected.to contain_glance_image_import_config("image_import_opts/image_import_plugins").with_value(
+                           "[%s]" % param_hash[:image_import_plugins])
+        end
+
+        it 'is_expected.to lay down default image_conversion image_import config' do
+          [
+            'image_conversion_output_format'
+          ].each do |config|
+            is_expected.to contain_glance_image_import_config("image_conversion/output_format").with_value(param_hash[config.intern])
+          end
+        end
+
         it 'is_expected.to lay down default cache config' do
           [
             'registry_host',
@@ -457,7 +468,7 @@ describe 'glance::api' do
 
   describe 'on unknown platforms' do
     let :facts do
-      OSDefaults.get_facts({ :osfamily => 'unknown' })
+      OSDefaults.get_facts({ :osfamily => 'unknown', :os => { :family => 'unknown', :release => { :major => '1'}}})
     end
     let(:params) { default_params }
 
