@@ -9,17 +9,12 @@ describe 'glance::registry' do
 
   let :default_params do
     {
-      :debug                  => false,
-      :use_stderr             => '<SERVICE DEFAULT>',
       :bind_host              => '<SERVICE DEFAULT>',
       :bind_port              => '9191',
       :workers                => facts[:os_workers],
-      :log_file               => '/var/log/glance/registry.log',
-      :log_dir                => '/var/log/glance',
       :enabled                => true,
       :manage_service         => true,
       :purge_config           => false,
-      :sync_db                => true,
       :os_region_name         => '<SERVICE DEFAULT>',
       :ca_file                => '<SERVICE DEFAULT>',
       :cert_file              => '<SERVICE DEFAULT>',
@@ -35,7 +30,6 @@ describe 'glance::registry' do
         :bind_port              => '9111',
         :workers                => '5',
         :enabled                => false,
-        :sync_db                => false,
         :os_region_name         => 'RegionOne2',
       }
     ].each do |param_set|
@@ -51,7 +45,6 @@ describe 'glance::registry' do
 
         it { is_expected.to contain_class 'glance::registry' }
         it { is_expected.to contain_class 'glance::registry::db' }
-        it { is_expected.to contain_class 'glance::registry::logging' }
 
       it { is_expected.to contain_service('glance-registry').with(
           'ensure'     => (param_hash[:manage_service] && param_hash[:enabled]) ? 'running' : 'stopped',
@@ -214,7 +207,7 @@ describe 'glance::registry' do
 
   describe 'on unknown platforms' do
     let :facts do
-      OSDefaults.get_facts({ :osfamily => 'unknown' })
+      OSDefaults.get_facts({ :osfamily => 'unknown', :os => { :family => 'unknown', :release => { :major => '1'}}})
     end
     let(:params) { default_params }
 
